#define ERROR                           1
#define NOT                             2
#define OR                              3
#define XOR                             4
#define AND                             5
#define NEAR                            6
#define ADJ                             7
#define LOVE                            8
#define HATE                            9
#define TERM                           10
#define PHR_TERM                       11
#define WILD_TERM                      12
#define BOOLEAN_FILTER                 13
#define QUOTE                          14
#define BRA                            15
#define KET                            16
